FeatureGenerator class

FeatureGenerator creates feature folder structure without external dependencies

Constructors

FeatureGenerator({required String name, required String basePath})

Properties

basePath String
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createDirectory(String relativePath) → void
Create directory structure
createFile(String relativePath, String content) → void
Create a file with content
createIndexFile(String relativePath, String content) → void
Create an empty index.dart file
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited